package com.xinelu.manage.service.patientblacklistabnormalcause.impl;

import com.xinelu.manage.domain.patientblacklistabnormalcause.PatientBlacklistAbnormalCause;
import com.xinelu.manage.mapper.patientblacklistabnormalcause.PatientBlacklistAbnormalCauseMapper;
import com.xinelu.manage.service.patientblacklistabnormalcause.IPatientBlacklistAbnormalCauseService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 患者黑名单异常原因Service业务层处理
 *
 * @author haown
 * @date 2024-03-01
 */
@Service
public class PatientBlacklistAbnormalCauseServiceImpl implements IPatientBlacklistAbnormalCauseService {
    @Resource
    private PatientBlacklistAbnormalCauseMapper patientBlacklistAbnormalCauseMapper;

    /**
     * 查询患者黑名单异常原因
     *
     * @param id 患者黑名单异常原因主键
     * @return 患者黑名单异常原因
     */
    @Override
    public PatientBlacklistAbnormalCause selectPatientBlacklistAbnormalCauseById(Long id) {
        return patientBlacklistAbnormalCauseMapper.selectPatientBlacklistAbnormalCauseById(id);
    }

    /**
     * 查询患者黑名单异常原因列表
     *
     * @param patientBlacklistAbnormalCause 患者黑名单异常原因
     * @return 患者黑名单异常原因
     */
    @Override
    public List<PatientBlacklistAbnormalCause> selectPatientBlacklistAbnormalCauseList(PatientBlacklistAbnormalCause patientBlacklistAbnormalCause) {
        return patientBlacklistAbnormalCauseMapper.selectPatientBlacklistAbnormalCauseList(patientBlacklistAbnormalCause);
    }

    /**
     * 新增患者黑名单异常原因
     *
     * @param patientBlacklistAbnormalCause 患者黑名单异常原因
     * @return 结果
     */
    @Override
    public int insertPatientBlacklistAbnormalCause(PatientBlacklistAbnormalCause patientBlacklistAbnormalCause) {
        patientBlacklistAbnormalCause.setCreateTime(LocalDateTime.now());
        return patientBlacklistAbnormalCauseMapper.insertPatientBlacklistAbnormalCause(patientBlacklistAbnormalCause);
    }

    /**
     * 修改患者黑名单异常原因
     *
     * @param patientBlacklistAbnormalCause 患者黑名单异常原因
     * @return 结果
     */
    @Override
    public int updatePatientBlacklistAbnormalCause(PatientBlacklistAbnormalCause patientBlacklistAbnormalCause) {
        patientBlacklistAbnormalCause.setUpdateTime(LocalDateTime.now());
        return patientBlacklistAbnormalCauseMapper.updatePatientBlacklistAbnormalCause(patientBlacklistAbnormalCause);
    }

    /**
     * 批量删除患者黑名单异常原因
     *
     * @param ids 需要删除的患者黑名单异常原因主键
     * @return 结果
     */
    @Override
    public int deletePatientBlacklistAbnormalCauseByIds(Long[] ids) {
        return patientBlacklistAbnormalCauseMapper.deletePatientBlacklistAbnormalCauseByIds(ids);
    }

    /**
     * 删除患者黑名单异常原因信息
     *
     * @param id 患者黑名单异常原因主键
     * @return 结果
     */
    @Override
    public int deletePatientBlacklistAbnormalCauseById(Long id) {
        return patientBlacklistAbnormalCauseMapper.deletePatientBlacklistAbnormalCauseById(id);
    }
}
